@@ -6,17 +6,20 @@ import sys
 import requests
 from dotenv import load_dotenv
 
-load_dotenv()
 
-GITHUB_ACCESS_TOKEN = os.getenv("GITHUB_ACCESS_TOKEN")
-VERCEL_ACCESS_TOKEN = os.getenv("VERCEL_ACCESS_TOKEN")
+def get_token():
+    load_dotenv()
+    GITHUB_ACCESS_TOKEN = os.getenv("GITHUB_ACCESS_TOKEN")
+    VERCEL_ACCESS_TOKEN = os.getenv("VERCEL_ACCESS_TOKEN")
 
-if not GITHUB_ACCESS_TOKEN or not VERCEL_ACCESS_TOKEN:
-    print("Please set GITHUB_ACCESS_TOKEN and VERCEL_ACCESS_TOKEN in your .env file")
-    sys.exit(1)
+    if not GITHUB_ACCESS_TOKEN or not VERCEL_ACCESS_TOKEN:
+        print("Please set GITHUB_ACCESS_TOKEN and VERCEL_ACCESS_TOKEN in your .env file")
+        sys.exit(1)
+    return GITHUB_ACCESS_TOKEN, VERCEL_ACCESS_TOKEN
 
 
 def get_repo_info(github_repo_url):
+    GITHUB_ACCESS_TOKEN, VERCEL_ACCESS_TOKEN = get_token()
     github_api_url = "https://api.github.com/repos/" + "/".join(github_repo_url.split("/")[-2:])
     headers = {"Authorization": f"token {GITHUB_ACCESS_TOKEN}"}
     response = requests.get(github_api_url, headers=headers)
@@ -25,6 +28,7 @@ def get_repo_info(github_repo_url):
 
 
 def get_vercel_project_id(vercel_project_name):
+    GITHUB_ACCESS_TOKEN, VERCEL_ACCESS_TOKEN = get_token()
     vercel_api_url = "https://api.vercel.com/v8/projects"
     headers = {
         "Authorization": f"Bearer {VERCEL_ACCESS_TOKEN}",
@@ -41,6 +45,7 @@ def get_vercel_project_id(vercel_project_name):
 
 
 def create_vercel_project(vercel_project_name, github_repo_info, vercel_team_id=None):
+    GITHUB_ACCESS_TOKEN, VERCEL_ACCESS_TOKEN = get_token()
     project_id = get_vercel_project_id(vercel_project_name)
 
     if project_id:
@@ -68,6 +73,7 @@ def create_vercel_project(vercel_project_name, github_repo_info, vercel_team_id=
 
 
 def get_github_repo_id(github_repo_url):
+    GITHUB_ACCESS_TOKEN, VERCEL_ACCESS_TOKEN = get_token()
     github_api_url = "https://api.github.com/repos/" + "/".join(github_repo_url.split("/")[-2:])
     headers = {"Authorization": f"token {GITHUB_ACCESS_TOKEN}"}
     response = requests.get(github_api_url, headers=headers)
@@ -77,6 +83,7 @@ def get_github_repo_id(github_repo_url):
 
 # https://vercel.com/docs/rest-api/endpoints
 def deploy_vercel_project(vercel_project_id, github_repo_info, vercel_team_id=None, ref="main"):
+    GITHUB_ACCESS_TOKEN, VERCEL_ACCESS_TOKEN = get_token()
     print("vercel_project_id", vercel_project_id)
     print("github_repo_info", github_repo_info)
     vercel_api_url = "https://api.vercel.com/v13/deployments"
